[Qa-jenkins-scm] [jenkins.debian.net] 01/01: reproducible debian dashboard: correctly count usertagged bugs excluding ftbfs

Holger Levsen holger at moszumanska.debian.org
Wed Feb 3 14:02:02 UTC 2016


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit efc01d180beabea3aede34411d879d0a450fff43
Author: Holger Levsen <holger at layer-acht.org>
Date:   Wed Feb 3 15:01:51 2016 +0100

    reproducible debian dashboard: correctly count usertagged bugs excluding ftbfs
---
 bin/reproducible_html_dashboard.sh | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/bin/reproducible_html_dashboard.sh b/bin/reproducible_html_dashboard.sh
index e1505d0..c6dd285 100755
--- a/bin/reproducible_html_dashboard.sh
+++ b/bin/reproducible_html_dashboard.sh
@@ -270,10 +270,11 @@ write_usertag_table() {
 				let "TTOTAL=TTOTAL+TOTAL"
 			fi
 		done
 		# now subtract the ftbfs bugs again (=the last value)
 		# as those others are the ones we really care about
-		let "REPRODUCIBLE_TOPEN=TOPEN-VALUE"
-		let "REPRODUCIBLE_TDONE=TDONE-VALUE"
+		let "CCOUNT=COUNT-1"
+		let "REPRODUCIBLE_TOPEN=TOPEN-$(echo $RESULT | cut -d "|" -f$CCOUNT)"
+		let "REPRODUCIBLE_TDONE=TDONE-$(echo $RESULT | cut -d "|" -f$COUNT)"
 		let "REPRODUCIBLE_TTOTAL=REPRODUCIBLE_TOPEN+REPRODUCIBLE_TDONE"
 		write_page "<tr><td>Sum of <a href=\"https://wiki.debian.org/ReproducibleBuilds/Contribute#How_to_report_bugs\">bugs with usertags related to reproducible builds</a>, excluding those tagged 'ftbfs'</td><td>$REPRODUCIBLE_TOPEN</td><td>$REPRODUCIBLE_TDONE</td><td>$REPRODUCIBLE_TTOTAL</td></tr>"
 		write_page "<tr><td>Sum of all bugs with usertags related to reproducible builds</td><td>$TOPEN</td><td>$TDONE</td><td>$TTOTAL</td></tr>"
@@ -270,10 +270,11 @@ write_usertag_table() {
 			fi
 		done
-		# now subtract the ftbfs bugs again (=the last value)
+		# now subtract the ftbfs bugs again (=the last fields from the result)
 		# as those others are the ones we really care about

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list